# rde2util

`rde2util`では、構造化処理を実行するためのユーティリティが定義されています。

## Meta

::: src.rdetoolkit.rde2util.Meta
    options:
        members:
            - assign_vals
            - writefile
            - _metadata_validation
            - _process_action
            - _process_unit

## StorageDir

::: src.rdetoolkit.rde2util.StorageDir
    handler: python
    options:
        members:
            - get_datadir
            - get_specific_outputdir
            - _make_data_basedir

## get_default_values

::: src.rdetoolkit.rde2util.get_default_values

## CharDecEncoding

::: src.rdetoolkit.rde2util.CharDecEncoding
    options:
        members:
            - detect_text_file_encoding

## unzip_japanese_zip

::: src.rdetoolkit.rde2util.unzip_japanese_zip

## read_from_json_file

::: src.rdetoolkit.rde2util.read_from_json_file

## write_to_json_file

::: src.rdetoolkit.rde2util.write_to_json_file

## castval

::: src.rdetoolkit.rde2util.castval

## ValueCaster

::: src.rdetoolkit.rde2util.ValueCaster

## dict2meta

::: src.rdetoolkit.rde2util.dict2meta
